batgrep
batgrep is is a CLI tool I build by reading The Rust Book. Rust is so
amazing.
Structs
- Config
Args ConfigArgsstruct will hold all the configuration variables such as query(s) to be searched, filepath(s) of file(s) to be searched and other flags for different functionalities.
Functions
- run
run()will be responsible for running different types of search functions depending on the types of flags passed whenbatgrepis called. It will call suitable functions and print matched lines tostdoutif any match is found.